@@ -1,15 +1,15 @@
 from typing import TYPE_CHECKING, Mapping
 
 import pdtypes
-from simplug import Simplug
+from datar.core.plugin import plugin
 
+# Attach version to the plugin
+from .version import __version__  # noqa: F401
 from .pandas import read_csv
 
 if TYPE_CHECKING:
     from .pandas import DataFrame
 
-plugin = Simplug("datar")
-
 
 @plugin.impl
 def setup():
@@ -130,8 +130,8 @@ def forcats_api():
 
 
 @plugin.impl
-def other_api():
-    from .api.other import (
+def misc_api():
+    from .api.misc import (
         itemgetter,
         attrgetter,
         pd_cat,
@@ -153,7 +153,6 @@ def other_api():
 def get_versions():
     import pandas
     from datar.core.options import get_option
-    from .version import __version__
 
     out = {
         "datar-pandas": __version__,
